/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.geronimo.samples.inventory.services;

import java.util.List;

import org.apache.geronimo.samples.inventory.Item;
import org.apache.geronimo.samples.inventory.dao.ItemDAO;
import org.apache.geronimo.samples.inventory.exception.DuplicateItemIdException;
import org.apache.geronimo.samples.inventory.exception.NotSufficientQuantityException;
import org.apache.geronimo.samples.inventory.exception.ItemException;


public class InventoryManager {

    public List<Item> getItems() throws ItemException {
        ItemDAO dao = new ItemDAO();
        return dao.getItems();
    }

    public void issueItem(String itemNo, int quantity) throws NotSufficientQuantityException, ItemException {
        ItemDAO dao = new ItemDAO();

        int qoh = dao.getQOH(itemNo);

        if (qoh < quantity) throw new NotSufficientQuantityException();

        dao.updateQOH(itemNo, (qoh - quantity));
    }

    public void recvItem(String itemNo, int quantity) throws ItemException {
        ItemDAO dao = new ItemDAO();

        int qoh = dao.getQOH(itemNo);

        dao.updateQOH(itemNo, (qoh + quantity));
    }

    public void addItem(String itemNo, String itemName, String desc) throws DuplicateItemIdException, ItemException {
        ItemDAO dao = new ItemDAO();

        if (dao.isItemIdExists(itemNo)) throw new DuplicateItemIdException();
        Item item = new Item();

        item.setItemNo(itemNo);
        item.setItemName(itemName);
        item.setDescription(desc);

        dao.addItem(item);

    }

}
